command_palette
library
Classes
CommandPalette
Command palette is a widget that is summoned by a keyboard shortcut, or by
programmatic means.
CommandPaletteAction
Action that is presented in the command palette. These are the things the
user will be presented with to choose from
CommandPaletteConfig
Configuration options for the command palette
CommandPaletteStyle
Used to style a CommandPalette
Filter
Collection of various String based filters. Everything in here is an
adaptation of the filtering library used in VSCode
FilterMatch
A match for a given String. Has the start and end indices of the substring
containing the match
KeyboardKeyIcon
Creates an icon which represents a keyboard key.
This is done either with existing IconData which represents the key, or
with a String
MatchedCommandPaletteAction
An action that was matched to the entered query. Contains both the action
itself and a list of the matches contained within